import React, { useEffect, useState, useRef } from 'react';
import Chart from 'chart.js/auto';
import defaultApis from './defaultApis';

interface ChartComponentProps {
  api: keyof typeof defaultApis;
}

const ChartComponent: React.FC<ChartComponentProps> = ({ api }) => {
  const [marketData, setMarketData] = useState<any>(null);
  const [isLoading, setIsLoading] = useState<boolean>(true);
  const [error, setError] = useState<string | null>(null);
  const chartRef = useRef<Chart<'pie', number[], string> | null>(null);
 
 
  useEffect(() => {
    const fetchData = async () => {
      try {
        setIsLoading(true);
        const response = await fetch(defaultApis[api], {
        // const response = await fetch("api.unleashnfts.com/api/v1/market/trend?currency=usd&time_range=24h&include_washtrade=true", {
          headers: {
            'x-api-key': 'e36cc4c68e914b0b8aef6e8c7756035e'
          }
        });
        if (!response.ok) {
          throw new Error('Network response was not ok');
        }
        const jsonData = await response.json();
        setMarketData(jsonData.metric_values);
        setError(null);
      } catch (error) {
        console.error('Error fetching data:', error);
        setError('Failed to fetch data');
      } finally {
        setIsLoading(false);
      }
    };

    fetchData();
  }, [api]);

  useEffect(() => {
    if (!marketData) return;

    const ctx = document.getElementById('pieChart') as HTMLCanvasElement;
    if (chartRef.current) {
      chartRef.current.destroy();
    }
    // const label = marketData?.metrics || 'Market Data';
    chartRef.current = new Chart(ctx, {
      type: 'pie',
      data: {
        labels: Object.keys(marketData),
        datasets: [{
          label: Object.keys(marketData)[0],
          data: Object.values(marketData),
          backgroundColor: [
            'rgba(255, 99, 132, 0.5)',
            'rgba(54, 162, 235, 0.5)',
          ],
          borderColor: [
            'rgba(255, 99, 132, 1)',
            'rgba(54, 162, 235, 1)',
          ],
          borderWidth: 1
        }]
      },
      options: {
        responsive: true,
        plugins: {
          legend: {
            position: 'top',
          },
          title: {
            display: true,
            text: Object.keys(marketData)[0]
          }
        }
      }
    });
  }, [marketData]);

  if (isLoading) {
    return <div>Loading...</div>;
  }

  if (error) {
    return <div>Error: {error}</div>;
  }

  return (
    <div>
      <h1>{Object.keys(marketData)[0].toUpperCase()}</h1>
      <canvas id="pieChart" width={300} height={300}></canvas>
    </div>
  );
};

export default ChartComponent;
