import React, { useEffect, useState } from 'react';
import Chart from 'chart.js/auto';

interface MarketTrendChartProps {
    currency?: string;
    blockchain?: number;
    metrics: string[];
    time_range?: string;
    time_range_start?: Date;
    time_range_end?: Date;
    include_washtrade?: boolean;
    apiKey: string;
}

const MarketTrends: React.FC<MarketTrendChartProps> = ({
    currency,
    blockchain,
    metrics,
    time_range,
    time_range_start,
    time_range_end,
    include_washtrade,
    apiKey
}) => {
    const [chartData, setChartData] = useState<any>(null);

    useEffect(() => {
        const fetchData = async () => {
            try {
                const params = new URLSearchParams();
                if (currency) params.append('currency', currency);
                if (blockchain) params.append('blockchain', blockchain.toString());
                params.append('metrics', metrics.join(','));
                if (time_range) params.append('time_range', time_range);
                if (time_range_start) params.append('time_range_start', time_range_start.toISOString());
                if (time_range_end) params.append('time_range_end', time_range_end.toISOString());
                if (include_washtrade !== undefined) params.append('include_washtrade', include_washtrade.toString());

                const apiUrl = `https://api.unleashnfts.com/api/v1/market/trend?${params}`;
                
                const response = await fetch(apiUrl, {
                  headers: {
                    'x-api-key': apiKey
                  }
                });
                
                if (!response.ok) {
                    throw new Error('Failed to fetch data');
                }
                const data = await response.json();
                setChartData(data);
            } catch (error) {
                console.error('Error fetching data:', error);
            }
        };

        fetchData();
    }, [currency, blockchain, metrics, time_range, time_range_start, time_range_end, include_washtrade, apiKey]);

    useEffect(() => {
        if (!chartData) return;

        // Extract data from chartData and create a chart using Chart.js
        // Example:
        // const labels = Object.keys(chartData.metric_values);
        // const values = Object.values(chartData.metric_values);
        // Create Chart.js chart with labels and values
    }, [chartData]);

    return (
        <div>
            {/* Display loading indicator or error message if needed */}
            {/* Render Chart.js chart here */}
        </div>
    );
};

export default MarketTrends;
